<?php

namespace Drupal\Tests\migmag\Unit;

use Drupal\migmag\Utility\MigMagMigrationUtility;
use Drupal\Tests\UnitTestCase;

/**
 * Tests MigMagMigrationUtility.
 *
 * @coversDefaultClass \Drupal\migmag\Utility\MigMagMigrationUtility
 *
 * @group migmag
 */
class MigMagMigrationUtilityTest extends UnitTestCase {

  /**
   * @covers \Drupal\migmag\Utility\MigMagMigrationUtility::getAssociativeMigrationProcess
   *
   * @dataProvider providerGetAssociativeMigrationProcess
   */
  public function testGetAssociativeMigrationProcess($test_process, array $expected_process_pipeline) {
    $this->assertSame(
      $expected_process_pipeline,
      MigMagMigrationUtility::getAssociativeMigrationProcess($test_process)
    );
  }

  /**
   * Data provider for ::testGetAssociativeMigrationProcess.
   *
   * @return array
   *   The test cases.
   */
  public function providerGetAssociativeMigrationProcess(): array {
    return [
      'String' => [
        'process' => 'foo',
        'expected' => [
          [
            'plugin' => 'get',
            'source' => 'foo',
          ],
        ],
      ],
      'Single config' => [
        'process' => [
          'plugin' => 'foo',
          'source' => 'bar',
        ],
        'expected' => [
          [
            'plugin' => 'foo',
            'source' => 'bar',
          ],
        ],
      ],
      'Indexed array of configs' => [
        'process' => [
          [
            'plugin' => 'foo',
            'source' => 'bar',
            'other_config' => 'baz',
          ],
          ['plugin' => 'foobarbaz'],
        ],
        'expected' => [
          [
            'plugin' => 'foo',
            'source' => 'bar',
            'other_config' => 'baz',
          ],
          ['plugin' => 'foobarbaz'],
        ],
      ],
      'Keyed array of configs' => [
        'process' => [
          3 => [
            'plugin' => 'foo',
            'source' => 'bar',
            'other_config' => 'baz',
          ],
          'a key here' => ['plugin' => 'foobarbaz'],
        ],
        'expected' => [
          3 => [
            'plugin' => 'foo',
            'source' => 'bar',
            'other_config' => 'baz',
          ],
          'a key here' => ['plugin' => 'foobarbaz'],
        ],
      ],
    ];
  }

}
